from rre import rre

def test_email():
    assert len(rre.email("test@test.com")) > 0
    assert len(rre.email("test@test")) == 0

def test_url():
    assert len(rre.url("check it at test.com")) > 0
    assert len(rre.url("check it at testcom")) == 0
    assert len(rre.url("check it at https://test.com")) > 0
    assert len(rre.url("check it at https://testcom")) == 0

def test_multiple_punctuation():
    assert len(rre.multiple_punctuation("how are you??")) > 0
    assert len(rre.multiple_punctuation("how are you?!")) > 0
    assert len(rre.multiple_punctuation("&&&&& that's how it is")) > 0
    assert len(rre.multiple_punctuation("& that's how it is")) == 0
    assert len(rre.multiple_punctuation("how are you?")) == 0
    assert len(rre.multiple_punctuation("look over there!")) == 0


import re
import json
import os

basedir = os.path.dirname(os.path.abspath(__file__))
regexes_file = os.path.join(basedir,'regexes.json')

regexes = open(regexes_file)
regexes_dict = json.load(regexes)


class rre:
    pass

for item in regexes_dict:
    @staticmethod
    def func(search, item=item):
        regex = regexes_dict[item]
        result = re.findall(regex, search)
        return result
    func_name = item
    setattr(rre, func_name, func)